@@ -19,6 +19,7 @@ package org.gradle.composite.internal;
 import com.google.common.collect.Maps;
 import org.gradle.api.initialization.IncludedBuild;
 
+import java.util.Collection;
 import java.util.Map;
 
 public class DefaultIncludedBuilds implements IncludedBuilds {
@@ -29,7 +30,7 @@ public class DefaultIncludedBuilds implements IncludedBuilds {
     }
 
     @Override
-    public Iterable<IncludedBuild> getBuilds() {
+    public Collection<IncludedBuild> getBuilds() {
         return builds.values();
     }
 
