@@ -15,7 +15,9 @@
  */
 package org.gradle.api.internal.changedetection.state;
 
+import com.google.common.collect.ImmutableSortedMap;
 import org.gradle.api.internal.TaskInternal;
+import org.gradle.api.internal.changedetection.changes.IncrementalTaskInputsInternal;
 
 import javax.annotation.Nullable;
 
@@ -28,6 +30,10 @@ public interface TaskHistoryRepository {
 
         TaskExecution getCurrentExecution();
 
-        void update();
+        void updateCurrentExecution(IncrementalTaskInputsInternal taskInputs);
+
+        void updateCurrentExecutionWithOutputs(IncrementalTaskInputsInternal taskInputs, ImmutableSortedMap<String, FileCollectionSnapshot> newOutputSnapshot);
+
+        void persist();
     }
 }
