@@ -22,6 +22,7 @@ import org.gradle.api.internal.project.ProjectIdentifier;
 import org.gradle.internal.FileUtils;
 import org.gradle.internal.file.PathToFileResolver;
 import org.gradle.internal.scripts.ScriptFileResolver;
+import org.gradle.util.NameValidator;
 import org.gradle.util.Path;
 
 import javax.annotation.Nullable;
@@ -52,6 +53,7 @@ public class DefaultProjectDescriptor implements ProjectDescriptor, ProjectIdent
     public DefaultProjectDescriptor(DefaultProjectDescriptor parent, String name, File dir,
                                     ProjectDescriptorRegistry projectDescriptorRegistry, PathToFileResolver fileResolver,
                                     @Nullable ScriptFileResolver scriptFileResolver) {
+        NameValidator.validate(name);
         this.parent = parent;
         this.name = name;
         this.fileResolver = fileResolver;
@@ -86,6 +88,7 @@ public class DefaultProjectDescriptor implements ProjectDescriptor, ProjectIdent
     }
 
     public void setName(String name) {
+        NameValidator.validate(name);
         projectDescriptorRegistry.changeDescriptorPath(path, path(name));
         this.name = name;
     }
