@@ -19,16 +19,21 @@ import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
 import org.gradle.api.InvalidUserDataException;
 import org.gradle.api.credentials.Credentials;
-import org.gradle.api.internal.artifacts.ImmutableModuleIdentifierFactory;
 import org.gradle.api.internal.artifacts.ivyservice.CacheLockingManager;
+import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.StartParameterResolutionOverride;
+import org.gradle.api.internal.artifacts.ivyservice.resolutionstrategy.DefaultExternalResourceCachePolicy;
+import org.gradle.api.internal.artifacts.ivyservice.resolutionstrategy.ExternalResourceCachePolicy;
 import org.gradle.api.internal.file.TemporaryFileProvider;
 import org.gradle.authentication.Authentication;
+import org.gradle.cache.internal.ProducerGuard;
 import org.gradle.internal.authentication.AuthenticationInternal;
 import org.gradle.internal.logging.progress.ProgressLoggerFactory;
-import org.gradle.internal.progress.BuildOperationExecutor;
+import org.gradle.internal.operations.BuildOperationExecutor;
+import org.gradle.internal.resource.ExternalResourceName;
 import org.gradle.internal.resource.cached.CachedExternalResourceIndex;
 import org.gradle.internal.resource.connector.ResourceConnectorFactory;
 import org.gradle.internal.resource.connector.ResourceConnectorSpecification;
+import org.gradle.internal.resource.local.FileResourceRepository;
 import org.gradle.internal.resource.transfer.ExternalResourceConnector;
 import org.gradle.internal.resource.transport.ResourceConnectorRepositoryTransport;
 import org.gradle.internal.resource.transport.file.FileTransport;
@@ -47,8 +52,10 @@ public class RepositoryTransportFactory {
     private final ProgressLoggerFactory progressLoggerFactory;
     private final BuildCommencedTimeProvider timeProvider;
     private final CacheLockingManager cacheLockingManager;
-    private final ImmutableModuleIdentifierFactory moduleIdentifierFactory;
     private final BuildOperationExecutor buildOperationExecutor;
+    private final StartParameterResolutionOverride startParameterResolutionOverride;
+    private final ProducerGuard<ExternalResourceName> producerGuard;
+    private final FileResourceRepository fileRepository;
 
     public RepositoryTransportFactory(Collection<ResourceConnectorFactory> resourceConnectorFactory,
                                       ProgressLoggerFactory progressLoggerFactory,
@@ -56,15 +63,19 @@ public class RepositoryTransportFactory {
                                       CachedExternalResourceIndex<String> cachedExternalResourceIndex,
                                       BuildCommencedTimeProvider timeProvider,
                                       CacheLockingManager cacheLockingManager,
-                                      ImmutableModuleIdentifierFactory moduleIdentifierFactory,
-                                      BuildOperationExecutor buildOperationExecutor) {
+                                      BuildOperationExecutor buildOperationExecutor,
+                                      StartParameterResolutionOverride startParameterResolutionOverride,
+                                      ProducerGuard<ExternalResourceName> producerGuard,
+                                      FileResourceRepository fileRepository) {
         this.progressLoggerFactory = progressLoggerFactory;
         this.temporaryFileProvider = temporaryFileProvider;
         this.cachedExternalResourceIndex = cachedExternalResourceIndex;
         this.timeProvider = timeProvider;
         this.cacheLockingManager = cacheLockingManager;
-        this.moduleIdentifierFactory = moduleIdentifierFactory;
         this.buildOperationExecutor = buildOperationExecutor;
+        this.startParameterResolutionOverride = startParameterResolutionOverride;
+        this.producerGuard = producerGuard;
+        this.fileRepository = fileRepository;
 
         for (ResourceConnectorFactory connectorFactory : resourceConnectorFactory) {
             register(connectorFactory);
@@ -99,12 +110,18 @@ public class RepositoryTransportFactory {
         // file:// repos are treated differently
         // 1) we don't cache their files
         // 2) we don't do progress logging for "downloading"
-        if (Collections.singleton("file").containsAll(schemes)) {
-            return new FileTransport(name);
+        if (schemes.equals(Collections.singleton("file"))) {
+            return new FileTransport(name, fileRepository);
         }
         ResourceConnectorSpecification connectionDetails = new DefaultResourceConnectorSpecification(authentications);
+
         ExternalResourceConnector resourceConnector = connectorFactory.createResourceConnector(connectionDetails);
-        return new ResourceConnectorRepositoryTransport(name, progressLoggerFactory, temporaryFileProvider, cachedExternalResourceIndex, timeProvider, cacheLockingManager, resourceConnector, buildOperationExecutor, moduleIdentifierFactory);
+        resourceConnector = startParameterResolutionOverride.overrideExternalResourceConnnector(resourceConnector);
+
+        ExternalResourceCachePolicy cachePolicy = new DefaultExternalResourceCachePolicy();
+        cachePolicy = startParameterResolutionOverride.overrideExternalResourceCachePolicy(cachePolicy);
+
+        return new ResourceConnectorRepositoryTransport(name, progressLoggerFactory, temporaryFileProvider, cachedExternalResourceIndex, timeProvider, cacheLockingManager, resourceConnector, buildOperationExecutor, cachePolicy, producerGuard, fileRepository);
     }
 
     private void validateSchemes(Set<String> schemes) {
