@@ -17,23 +17,19 @@
 package org.gradle.api.tasks.compile;
 
 import com.google.common.collect.ImmutableList;
-import org.gradle.api.AntBuilder;
 import org.gradle.api.Incubating;
 import org.gradle.api.JavaVersion;
-import org.gradle.api.Task;
 import org.gradle.api.file.FileCollection;
 import org.gradle.api.file.FileTree;
 import org.gradle.api.internal.changedetection.changes.IncrementalTaskInputsInternal;
-import org.gradle.api.internal.changedetection.state.CachingFileHasher;
 import org.gradle.api.internal.file.FileOperations;
-import org.gradle.api.internal.tasks.CurrentJvmJavaToolChain;
-import org.gradle.api.internal.tasks.JavaHomeBasedJavaToolChain;
+import org.gradle.api.internal.tasks.JavaToolChainFactory;
 import org.gradle.api.internal.tasks.compile.AnnotationProcessorDetector;
 import org.gradle.api.internal.tasks.compile.CleaningJavaCompiler;
+import org.gradle.api.internal.tasks.compile.CompilerForkUtils;
 import org.gradle.api.internal.tasks.compile.DefaultJavaCompileSpec;
 import org.gradle.api.internal.tasks.compile.DefaultJavaCompileSpecFactory;
 import org.gradle.api.internal.tasks.compile.JavaCompileSpec;
-import org.gradle.api.internal.tasks.compile.JavaCompilerFactory;
 import org.gradle.api.internal.tasks.compile.incremental.IncrementalCompilerFactory;
 import org.gradle.api.internal.tasks.compile.incremental.analyzer.ClassAnalysisCache;
 import org.gradle.api.internal.tasks.compile.incremental.cache.CompileCaches;
@@ -41,37 +37,31 @@ import org.gradle.api.internal.tasks.compile.incremental.cache.GeneralCompileCac
 import org.gradle.api.internal.tasks.compile.incremental.deps.LocalClassSetAnalysisStore;
 import org.gradle.api.internal.tasks.compile.incremental.jar.JarSnapshotCache;
 import org.gradle.api.internal.tasks.compile.incremental.jar.LocalJarClasspathSnapshotStore;
-import org.gradle.api.specs.Spec;
 import org.gradle.api.tasks.CacheableTask;
 import org.gradle.api.tasks.Classpath;
 import org.gradle.api.tasks.CompileClasspath;
-import org.gradle.api.tasks.Internal;
 import org.gradle.api.tasks.Nested;
-import org.gradle.api.tasks.ParallelizableTask;
 import org.gradle.api.tasks.PathSensitive;
 import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.api.tasks.WorkResult;
 import org.gradle.api.tasks.incremental.IncrementalTaskInputs;
 import org.gradle.cache.CacheRepository;
-import org.gradle.internal.Factory;
-import org.gradle.internal.jvm.inspection.JvmVersionDetector;
+import org.gradle.internal.hash.FileHasher;
+import org.gradle.internal.hash.StreamHasher;
 import org.gradle.jvm.internal.toolchain.JavaToolChainInternal;
 import org.gradle.jvm.platform.JavaPlatform;
 import org.gradle.jvm.platform.internal.DefaultJavaPlatform;
 import org.gradle.jvm.toolchain.JavaToolChain;
 import org.gradle.language.base.internal.compile.Compiler;
 import org.gradle.language.base.internal.compile.CompilerUtil;
-import org.gradle.process.internal.ExecActionFactory;
-import org.gradle.util.DeprecationLogger;
 
 import javax.inject.Inject;
-import java.io.File;
 
 /**
  * Compiles Java source files.
  *
- * <pre autoTested=''>
+ * <pre class='autoTested'>
  *     apply plugin: 'java'
  *
  *     tasks.withType(JavaCompile) {
@@ -83,26 +73,13 @@ import java.io.File;
  *     }
  * </pre>
  */
-@ParallelizableTask
 @CacheableTask
 public class JavaCompile extends AbstractCompile {
-    private File dependencyCacheDir;
     private final CompileOptions compileOptions = new CompileOptions();
     private JavaToolChain toolChain;
 
     public JavaCompile() {
-        getOutputs().doNotCacheIf("Use depend is enabled", new Spec<Task>() {
-            @Override
-            public boolean isSatisfiedBy(Task task) {
-                return DeprecationLogger.whileDisabled(new Factory<Boolean>() {
-                    @Override
-                    @SuppressWarnings("deprecation")
-                    public Boolean create() {
-                        return compileOptions.isUseDepend();
-                    }
-                });
-            }
-        });
+        CompilerForkUtils.doNotCacheIfForkingViaExecutable(compileOptions, getOutputs());
     }
 
     /**
@@ -125,14 +102,7 @@ public class JavaCompile extends AbstractCompile {
         if (toolChain != null) {
             return toolChain;
         }
-        if (getOptions().isFork()) {
-            ForkOptions forkOptions = getOptions().getForkOptions();
-            File javaHome = forkOptions.getJavaHome();
-            if (javaHome != null) {
-                return new JavaHomeBasedJavaToolChain(javaHome, getJavaCompilerFactory(), getExecActionFactory(), getJvmVersionDetector());
-            }
-        }
-        return new CurrentJvmJavaToolChain(getJavaCompilerFactory(), getExecActionFactory());
+        return getJavaToolChainFactory().forCompileOptions(getOptions());
     }
 
     /**
@@ -155,7 +125,7 @@ public class JavaCompile extends AbstractCompile {
         DefaultJavaCompileSpec spec = createSpec();
         CompileCaches compileCaches = createCompileCaches();
         IncrementalCompilerFactory factory = new IncrementalCompilerFactory(
-            getFileOperations(), getCachingFileHasher(), getPath(), createCompiler(spec), source, compileCaches, (IncrementalTaskInputsInternal) inputs, getEffectiveAnnotationProcessorPath());
+            getFileOperations(), getStreamHasher(), getCachingFileHasher(), getPath(), createCompiler(spec), source, compileCaches, (IncrementalTaskInputsInternal) inputs, getEffectiveAnnotationProcessorPath());
         Compiler<JavaCompileSpec> compiler = factory.createCompiler();
         performCompilation(spec, compiler);
     }
@@ -184,7 +154,12 @@ public class JavaCompile extends AbstractCompile {
     }
 
     @Inject
-    protected CachingFileHasher getCachingFileHasher() {
+    protected StreamHasher getStreamHasher() {
+        throw new UnsupportedOperationException();
+    }
+
+    @Inject
+    protected FileHasher getCachingFileHasher() {
         throw new UnsupportedOperationException();
     }
 
@@ -204,22 +179,7 @@ public class JavaCompile extends AbstractCompile {
     }
 
     @Inject
-    protected JavaCompilerFactory getJavaCompilerFactory() {
-        throw new UnsupportedOperationException();
-    }
-
-    @Inject
-    protected Factory<AntBuilder> getAntBuilderFactory() {
-        throw new UnsupportedOperationException();
-    }
-
-    @Inject
-    protected JvmVersionDetector getJvmVersionDetector() {
-        throw new UnsupportedOperationException();
-    }
-
-    @Inject
-    protected ExecActionFactory getExecActionFactory() {
+    protected JavaToolChainFactory getJavaToolChainFactory() {
         throw new UnsupportedOperationException();
     }
 
@@ -232,7 +192,7 @@ public class JavaCompile extends AbstractCompile {
 
     private CleaningJavaCompiler createCompiler(JavaCompileSpec spec) {
         Compiler<JavaCompileSpec> javaCompiler = CompilerUtil.castCompiler(((JavaToolChainInternal) getToolChain()).select(getPlatform()).newCompiler(spec.getClass()));
-        return new CleaningJavaCompiler(javaCompiler, getAntBuilderFactory(), getOutputs());
+        return new CleaningJavaCompiler(javaCompiler, getOutputs());
     }
 
     @Nested
@@ -245,7 +205,6 @@ public class JavaCompile extends AbstractCompile {
         setDidWork(result.getDidWork());
     }
 
-    @SuppressWarnings("deprecation")
     private DefaultJavaCompileSpec createSpec() {
         final DefaultJavaCompileSpec spec = new DefaultJavaCompileSpecFactory(compileOptions).create();
         spec.setSource(getSource());
@@ -254,33 +213,12 @@ public class JavaCompile extends AbstractCompile {
         spec.setTempDir(getTemporaryDir());
         spec.setCompileClasspath(ImmutableList.copyOf(getClasspath()));
         spec.setAnnotationProcessorPath(ImmutableList.copyOf(getEffectiveAnnotationProcessorPath()));
-        File dependencyCacheDir = DeprecationLogger.whileDisabled(new Factory<File>() {
-            @Override
-            @SuppressWarnings("deprecation")
-            public File create() {
-                return getDependencyCacheDir();
-            }
-        });
-        spec.setDependencyCacheDir(dependencyCacheDir);
         spec.setTargetCompatibility(getTargetCompatibility());
         spec.setSourceCompatibility(getSourceCompatibility());
         spec.setCompileOptions(compileOptions);
         return spec;
     }
 
-    @Internal
-    @Deprecated
-    public File getDependencyCacheDir() {
-        DeprecationLogger.nagUserOfDiscontinuedMethod("JavaCompile.getDependencyCacheDir()");
-        return dependencyCacheDir;
-    }
-
-    @Deprecated
-    public void setDependencyCacheDir(File dependencyCacheDir) {
-        DeprecationLogger.nagUserOfDiscontinuedMethod("JavaCompile.setDependencyCacheDir()");
-        this.dependencyCacheDir = dependencyCacheDir;
-    }
-
     /**
      * Returns the compilation options.
      *
