@@ -17,7 +17,6 @@
 package org.gradle.internal.logging.sink;
 
 import com.google.common.base.Objects;
-import org.gradle.internal.logging.events.BatchOutputEventListener;
 import org.gradle.internal.logging.events.EndOutputEvent;
 import org.gradle.internal.logging.events.LogEvent;
 import org.gradle.internal.logging.events.OperationIdentifier;
@@ -31,7 +30,7 @@ import org.gradle.internal.logging.events.StyledTextOutputEvent;
 import org.gradle.internal.logging.events.UpdateNowEvent;
 import org.gradle.internal.logging.format.LogHeaderFormatter;
 import org.gradle.internal.progress.BuildOperationCategory;
-import org.gradle.internal.time.TimeProvider;
+import org.gradle.internal.time.Clock;
 import org.gradle.util.GUtil;
 
 import javax.annotation.Nullable;
@@ -46,11 +45,11 @@ import java.util.concurrent.TimeUnit;
  * An {@code org.gradle.logging.internal.OutputEventListener} implementation which generates output events to log the
  * progress of operations.
  */
-public class GroupingProgressLogEventGenerator extends BatchOutputEventListener {
+public class GroupingProgressLogEventGenerator implements OutputEventListener {
 
     private static final long LONG_RUNNING_TASK_OUTPUT_FLUSH_TIMEOUT = TimeUnit.SECONDS.toMillis(5);
     private final OutputEventListener listener;
-    private final TimeProvider timeProvider;
+    private final Clock clock;
     private final LogHeaderFormatter headerFormatter;
     private final boolean alwaysRenderTasks;
 
@@ -61,9 +60,9 @@ public class GroupingProgressLogEventGenerator extends BatchOutputEventListener
 
     private Object lastRenderedBuildOpId;
 
-    public GroupingProgressLogEventGenerator(OutputEventListener listener, TimeProvider timeProvider, LogHeaderFormatter headerFormatter, boolean alwaysRenderTasks) {
+    public GroupingProgressLogEventGenerator(OutputEventListener listener, Clock clock, LogHeaderFormatter headerFormatter, boolean alwaysRenderTasks) {
         this.listener = listener;
-        this.timeProvider = timeProvider;
+        this.clock = clock;
         this.headerFormatter = headerFormatter;
         this.alwaysRenderTasks = alwaysRenderTasks;
     }
@@ -122,7 +121,7 @@ public class GroupingProgressLogEventGenerator extends BatchOutputEventListener
         buildOpIdHierarchy.remove(buildOpId);
         OperationGroup group = operationsInProgress.remove(buildOpId);
         if (group != null) {
-            group.setStatus(completeEvent.getStatus());
+            group.setStatus(completeEvent.getStatus(), completeEvent.isFailed());
             group.flushOutput();
         }
     }
@@ -177,6 +176,7 @@ public class GroupingProgressLogEventGenerator extends BatchOutputEventListener
         private final BuildOperationCategory buildOperationCategory;
 
         private String status = "";
+        private boolean failed;
 
         private List<RenderableOutputEvent> bufferedLogs = new ArrayList<RenderableOutputEvent>();
 
@@ -192,14 +192,14 @@ public class GroupingProgressLogEventGenerator extends BatchOutputEventListener
         }
 
         private StyledTextOutputEvent header() {
-            return new StyledTextOutputEvent(lastUpdateTime, category, null, buildOpIdentifier, headerFormatter.format(loggingHeader, description, shortDescription, status));
+            return new StyledTextOutputEvent(lastUpdateTime, category, null, buildOpIdentifier, headerFormatter.format(loggingHeader, description, shortDescription, status, failed));
         }
 
         private void bufferOutput(RenderableOutputEvent output) {
             // Forward output immediately when the focus is on this operation group
             if (Objects.equal(buildOpIdentifier, lastRenderedBuildOpId)) {
                 listener.onOutput(output);
-                lastUpdateTime = timeProvider.getCurrentTime();
+                lastUpdateTime = clock.getCurrentTime();
             } else {
                 bufferedLogs.add(output);
             }
@@ -216,7 +216,7 @@ public class GroupingProgressLogEventGenerator extends BatchOutputEventListener
                 }
 
                 bufferedLogs.clear();
-                lastUpdateTime = timeProvider.getCurrentTime();
+                lastUpdateTime = clock.getCurrentTime();
                 lastRenderedBuildOpId = buildOpIdentifier;
             }
         }
@@ -227,8 +227,9 @@ public class GroupingProgressLogEventGenerator extends BatchOutputEventListener
             }
         }
 
-        private void setStatus(String status) {
+        private void setStatus(String status, boolean failed) {
             this.status = status;
+            this.failed = failed;
         }
 
         private boolean shouldForward() {
