@@ -36,7 +36,6 @@ import org.gradle.internal.logging.console.ThrottlingOutputEventListener;
 import org.gradle.internal.logging.console.WorkInProgressRenderer;
 import org.gradle.internal.logging.events.EndOutputEvent;
 import org.gradle.internal.logging.events.LogLevelChangeEvent;
-import org.gradle.internal.logging.events.MaxWorkerCountChangeEvent;
 import org.gradle.internal.logging.events.OutputEvent;
 import org.gradle.internal.logging.events.OutputEventListener;
 import org.gradle.internal.logging.events.ProgressCompleteEvent;
@@ -47,12 +46,10 @@ import org.gradle.internal.logging.text.StreamBackedStandardOutputListener;
 import org.gradle.internal.logging.text.StreamingStyledTextOutput;
 import org.gradle.internal.nativeintegration.console.ConsoleMetaData;
 import org.gradle.internal.nativeintegration.console.FallbackConsoleMetaData;
-import org.gradle.internal.time.TimeProvider;
-import org.gradle.internal.time.TrueTimeProvider;
+import org.gradle.internal.time.Clock;
 
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
-import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
 
 /**
@@ -63,8 +60,7 @@ import java.util.concurrent.atomic.AtomicReference;
 public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
     private final Object lock = new Object();
     private final AtomicReference<LogLevel> logLevel = new AtomicReference<LogLevel>(LogLevel.LIFECYCLE);
-    private final AtomicInteger maxWorkerCount = new AtomicInteger();
-    private final TimeProvider timeProvider;
+    private final Clock clock;
     private final ListenerBroadcast<OutputEventListener> formatters = new ListenerBroadcast<OutputEventListener>(OutputEventListener.class);
     private final ListenerBroadcast<StandardOutputListener> stdoutListeners = new ListenerBroadcast<StandardOutputListener>(StandardOutputListener.class);
     private final ListenerBroadcast<StandardOutputListener> stderrListeners = new ListenerBroadcast<StandardOutputListener>(StandardOutputListener.class);
@@ -76,12 +72,8 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
     private StreamBackedStandardOutputListener stdErrListener;
     private OutputEventListener console;
 
-    public OutputEventRenderer() {
-        this(new TrueTimeProvider());
-    }
-
-    OutputEventRenderer(TimeProvider timeProvider) {
-        this.timeProvider = timeProvider;
+    public OutputEventRenderer(Clock clock) {
+        this.clock = clock;
         OutputEventListener stdOutChain = new LazyListener(new Factory<OutputEventListener>() {
             @Override
             public OutputEventListener create() {
@@ -102,7 +94,7 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
     public Snapshot snapshot() {
         synchronized (lock) {
             // Currently only snapshot the console output listener. Should snapshot all output listeners, and cleanup in restore()
-            return new SnapshotImpl(logLevel.get(), console, maxWorkerCount.get());
+            return new SnapshotImpl(logLevel.get(), console);
         }
     }
 
@@ -114,11 +106,7 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
                 configure(snapshot.logLevel);
             }
 
-            if (snapshot.maxWorkerCount != maxWorkerCount.get()) {
-                configureMaxWorkerCount(snapshot.maxWorkerCount);
-            }
             // TODO - also close console when it is replaced
-            // TODO - remove console from formatters
             if (snapshot.console != console) {
                 if (snapshot.console == null) {
                     formatters.remove(console);
@@ -225,10 +213,10 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
             new BuildStatusRenderer(
                 new WorkInProgressRenderer(
                     new BuildLogLevelFilterRenderer(
-                        new GroupingProgressLogEventGenerator(new StyledTextOutputBackedRenderer(console.getBuildOutputArea()), timeProvider, new PrettyPrefixedLogHeaderFormatter(), false)),
+                        new GroupingProgressLogEventGenerator(new StyledTextOutputBackedRenderer(console.getBuildOutputArea()), clock, new PrettyPrefixedLogHeaderFormatter(), false)),
                     console.getBuildProgressArea(), new DefaultWorkInProgressFormatter(consoleMetaData), new ConsoleLayoutCalculator(consoleMetaData)),
-                console.getStatusBar(), console, consoleMetaData, timeProvider),
-            timeProvider);
+                console.getStatusBar(), console, consoleMetaData, clock),
+            clock);
         synchronized (lock) {
             if (stdout && stderr) {
                 this.console = consoleChain;
@@ -242,7 +230,6 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
                 removeStandardErrorListener();
             }
             consoleChain.onOutput(new LogLevelChangeEvent(logLevel.get()));
-            consoleChain.onOutput(new MaxWorkerCountChangeEvent(maxWorkerCount.get()));
             formatters.add(this.console);
         }
         return this;
@@ -305,11 +292,6 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
         onOutput(new LogLevelChangeEvent(logLevel));
     }
 
-    @Override
-    public void configureMaxWorkerCount(int maxWorkerCount) {
-        onOutput(new MaxWorkerCountChangeEvent(maxWorkerCount));
-    }
-
     @Override
     public void onOutput(OutputEvent event) {
         if (event.getLogLevel() != null && event.getLogLevel().compareTo(logLevel.get()) < 0 && !isProgressEvent(event)) {
@@ -322,13 +304,6 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
                 return;
             }
             this.logLevel.set(newLogLevel);
-        } else if (event instanceof MaxWorkerCountChangeEvent) {
-            MaxWorkerCountChangeEvent changeEvent = (MaxWorkerCountChangeEvent) event;
-            int newMaxWorkerCount = changeEvent.getNewMaxWorkerCount();
-            if (newMaxWorkerCount == this.maxWorkerCount.get()) {
-                return;
-            }
-            this.maxWorkerCount.set(newMaxWorkerCount);
         }
         synchronized (lock) {
             formatters.getSource().onOutput(event);
@@ -342,12 +317,10 @@ public class OutputEventRenderer implements OutputEventListener, LoggingRouter {
     private static class SnapshotImpl implements Snapshot {
         private final LogLevel logLevel;
         private final OutputEventListener console;
-        private final int maxWorkerCount;
 
-        SnapshotImpl(LogLevel logLevel, OutputEventListener console, int maxWorkerCount) {
+        SnapshotImpl(LogLevel logLevel, OutputEventListener console) {
             this.logLevel = logLevel;
             this.console = console;
-            this.maxWorkerCount = maxWorkerCount;
         }
     }
 
